==> jc-1.4.0.tar.gz: java/security/spec/RSAPublicKeySpec.h <==
// public class java.security.spec.RSAPublicKeySpec

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 20efc1f066a9f0c2 java_security_spec_RSAPublicKeySpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_spec_RSAPublicKeySpec_H_
#define _JC_java_security_spec_RSAPublicKeySpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_java_security_spec_RSAPublicKeySpec$sub_refs	_jc_java_security_spec_RSAPublicKeySpec$sub_refs;
typedef struct _jc_java_security_spec_RSAPublicKeySpec$sub_nonrefs	_jc_java_security_spec_RSAPublicKeySpec$sub_nonrefs;
typedef struct _jc_java_security_spec_RSAPublicKeySpec$refs	_jc_java_security_spec_RSAPublicKeySpec$refs;
typedef struct _jc_java_security_spec_RSAPublicKeySpec$nonrefs	_jc_java_security_spec_RSAPublicKeySpec$nonrefs;
typedef struct _jc_java_security_spec_RSAPublicKeySpec$object	_jc_java_security_spec_RSAPublicKeySpec$object;

typedef const struct _jc_java_security_spec_RSAPublicKeySpec$vmethods	_jc_java_security_spec_RSAPublicKeySpec$vmethods;
typedef const struct _jc_java_security_spec_RSAPublicKeySpec$vtable	_jc_java_security_spec_RSAPublicKeySpec$vtable;
typedef const struct _jc_java_security_spec_RSAPublicKeySpec$vtype	_jc_java_security_spec_RSAPublicKeySpec$vtype;

// Constructors
extern void _jc_java_security_spec_RSAPublicKeySpec$method$_init$112bcad7f4f53827(_jc_env *, struct _jc_java_security_spec_RSAPublicKeySpec$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *);

// Virtual methods
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAPublicKeySpec$method$getModulus$430be9ccecc735d2(_jc_env *, struct _jc_java_security_spec_RSAPublicKeySpec$object *);
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAPublicKeySpec$method$getPublicExponent$6a90dc2525ab30b7(_jc_env *, struct _jc_java_security_spec_RSAPublicKeySpec$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_spec_RSAPublicKeySpec$method_info$getModulus$430be9ccecc735d2;
extern _jc_method _jc_java_security_spec_RSAPublicKeySpec$method_info$getPublicExponent$6a90dc2525ab30b7;

// Virtual methods structure
struct _jc_java_security_spec_RSAPublicKeySpec$vmethods {
	struct _jc_java_math_BigInteger$object	*(*getModulus$430be9ccecc735d2)(_jc_env *, struct _jc_java_security_spec_RSAPublicKeySpec$object *);
	struct _jc_java_math_BigInteger$object	*(*getPublicExponent$6a90dc2525ab30b7)(_jc_env *, struct _jc_java_security_spec_RSAPublicKeySpec$object *);
};

// Vtable
struct _jc_java_security_spec_RSAPublicKeySpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_spec_RSAPublicKeySpec$vmethods	java_security_spec_RSAPublicKeySpec;
};

// Vtype
struct _jc_java_security_spec_RSAPublicKeySpec$vtype {
	_jc_type			type;
	_jc_java_security_spec_RSAPublicKeySpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_spec_RSAPublicKeySpec$sub_refs {
	struct _jc_java_math_BigInteger$object	*modulus;
	struct _jc_java_math_BigInteger$object	*publicExponent;
};

// Reference instance fields (object)
struct _jc_java_security_spec_RSAPublicKeySpec$refs {
    _jc_java_security_spec_RSAPublicKeySpec$sub_refs	java_security_spec_RSAPublicKeySpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_spec_RSAPublicKeySpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_spec_RSAPublicKeySpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_spec_RSAPublicKeySpec$sub_nonrefs	java_security_spec_RSAPublicKeySpec;
};

// Object instance structure
struct _jc_java_security_spec_RSAPublicKeySpec$object {
	_jc_java_security_spec_RSAPublicKeySpec$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_spec_RSAPublicKeySpec$vtype	*vtype;
	_jc_java_security_spec_RSAPublicKeySpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_spec_RSAPublicKeySpec$vtype _jc_java_security_spec_RSAPublicKeySpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_spec_RSAPublicKeySpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_spec_RSAPublicKeySpec$class_object;

#endif	/* _JC_java_security_spec_RSAPublicKeySpec_H_ */

==> jc-1.4.6.tar.gz: java/security/spec/RSAPublicKeySpec.h <==
// public class java.security.spec.RSAPublicKeySpec

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 20efc1f066a9f0c2 java_security_spec_RSAPublicKeySpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_spec_RSAPublicKeySpec_H_
#define _JC_java_security_spec_RSAPublicKeySpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_java_security_spec_RSAPublicKeySpec$sub_refs	_jc_java_security_spec_RSAPublicKeySpec$sub_refs;
typedef struct _jc_java_security_spec_RSAPublicKeySpec$sub_nonrefs	_jc_java_security_spec_RSAPublicKeySpec$sub_nonrefs;
typedef struct _jc_java_security_spec_RSAPublicKeySpec$refs	_jc_java_security_spec_RSAPublicKeySpec$refs;
typedef struct _jc_java_security_spec_RSAPublicKeySpec$nonrefs	_jc_java_security_spec_RSAPublicKeySpec$nonrefs;
typedef struct _jc_java_security_spec_RSAPublicKeySpec$object	_jc_java_security_spec_RSAPublicKeySpec$object;

typedef const struct _jc_java_security_spec_RSAPublicKeySpec$vmethods	_jc_java_security_spec_RSAPublicKeySpec$vmethods;
typedef const struct _jc_java_security_spec_RSAPublicKeySpec$vtable	_jc_java_security_spec_RSAPublicKeySpec$vtable;
typedef const struct _jc_java_security_spec_RSAPublicKeySpec$vtype	_jc_java_security_spec_RSAPublicKeySpec$vtype;

// Constructors
extern void _jc_java_security_spec_RSAPublicKeySpec$method$_init$112bcad7f4f53827(_jc_env *, struct _jc_java_security_spec_RSAPublicKeySpec$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAPublicKeySpec$method$getModulus$430be9ccecc735d2(_jc_env *, struct _jc_java_security_spec_RSAPublicKeySpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAPublicKeySpec$method$getPublicExponent$6a90dc2525ab30b7(_jc_env *, struct _jc_java_security_spec_RSAPublicKeySpec$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_spec_RSAPublicKeySpec$method_info$getModulus$430be9ccecc735d2;
extern _jc_method _jc_java_security_spec_RSAPublicKeySpec$method_info$getPublicExponent$6a90dc2525ab30b7;

// Virtual methods structure
struct _jc_java_security_spec_RSAPublicKeySpec$vmethods {
	struct _jc_java_math_BigInteger$object	*(*getModulus$430be9ccecc735d2)(_jc_env *, struct _jc_java_security_spec_RSAPublicKeySpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getPublicExponent$6a90dc2525ab30b7)(_jc_env *, struct _jc_java_security_spec_RSAPublicKeySpec$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_spec_RSAPublicKeySpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_spec_RSAPublicKeySpec$vmethods	java_security_spec_RSAPublicKeySpec;
};

// Vtype
struct _jc_java_security_spec_RSAPublicKeySpec$vtype {
	_jc_type			type;
	_jc_java_security_spec_RSAPublicKeySpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_spec_RSAPublicKeySpec$sub_refs {
	struct _jc_java_math_BigInteger$object	*modulus;
	struct _jc_java_math_BigInteger$object	*publicExponent;
};

// Reference instance fields (object)
struct _jc_java_security_spec_RSAPublicKeySpec$refs {
    _jc_java_security_spec_RSAPublicKeySpec$sub_refs	java_security_spec_RSAPublicKeySpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_spec_RSAPublicKeySpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_spec_RSAPublicKeySpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_spec_RSAPublicKeySpec$sub_nonrefs	java_security_spec_RSAPublicKeySpec;
};

// Object instance structure
struct _jc_java_security_spec_RSAPublicKeySpec$object {
	_jc_java_security_spec_RSAPublicKeySpec$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_spec_RSAPublicKeySpec$vtype	*vtype;
	_jc_java_security_spec_RSAPublicKeySpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_spec_RSAPublicKeySpec$vtype _jc_java_security_spec_RSAPublicKeySpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_spec_RSAPublicKeySpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_spec_RSAPublicKeySpec$class_object;

#endif	/* _JC_java_security_spec_RSAPublicKeySpec_H_ */
